@@ -89,7 +89,7 @@ CLI_COMMANDS_HELP = {
                 KEY: The key of the configuration. It may also be provided using the '--key' option.\n
                 VALUE: The value for the configuration. It may also be provided using the '--value' option.\n
                 """,
-        'delete': """Get DSO application configuration.\n
+        'unset': """Unset DSO application configuration.\n
                 ** Tips: 1) Use --local or --global to get local or global configuration only.\n
                 KEY: The key of the configuration
                 """,
@@ -98,6 +98,11 @@ CLI_COMMANDS_HELP = {
                 The option '--working-dir' can be used to specify a different working directory than the current directory where dso is running in.\n
                 """,
     },
+    'network': {
+        'layout_subnet_plan': """Layout subnet plan.\n
+                """,
+
+    }
 }
 
 CLI_COMMANDS_SHORT_HELP = {
@@ -142,23 +147,33 @@ CLI_COMMANDS_SHORT_HELP = {
     'config': {
         'get': "Get DSO application configuration(s).",
         'set': "Set the DSO application configuration(s).",
-        'delete': "Delete a DSO application configuration.",
+        'unset': "Delete a DSO application configuration.",
         'init': "Initialize DSO configuration for the working directory.",
     },
+    'network': {
+        'layout_subnet_plan': "Layout subnet plan group.",
+
+    }
+
 }
 CLI_PARAMETERS_HELP = {
     'common': {
         'working_dir': "Path to a (local) directory where the DSO application configuration resides. By default, the current working directory will be used if the option is not provided.",
         'verbosity' : "Specify the logging verbosity, where 0 is for logging critical fatal errors only, 1 also logs error messages, 2 also logs warnings, 3 also logs information messages, 4 also logs debug messages, and finally 5 logs everything.",
-        'stage' : "Target a specific stage using the stage identifier, which is combination of a name and an optional number, where name must conform to ^([a-zA-Z][a-zA-Z0-9]+)$ regex expression. If no /<number> is specified, the default environment (/0) in the given context will be targeted.",
+        'stage' : "Target a specific stage using the stage identifier, which is combination of a name and an optional number, where name must conform to ^([a-zA-Z][a-zA-Z0-9]+)$ regex expression. If no /<number> is specified, the default environment (/0) in the given context will be target.",
         'input' : "Path to a (local) file defining the input data. Use '-' to read from the shell pipe or stdin. Use '--format' to specify the format if needed.",
         'format': "Specify the format of the output or the input if mixed with the '--input' option.",
         'config': "Comma separated list of key/value pairs to temporarily override the current DSO application configurations. It takes effect only while executing the command and does not have any lasting effect on the DSO application configuration or subsequent command executions.",
         'query': "Customize output using JMESPath query language.",
         'query_all': "Include all the available fields in the ouput.",
-        'global_scope': "Use the global context.",
-        'project_scope': "Use the project context.",
+        'global_scope': "Use the global scope.",
+        'project_scope': "Use the project scope.",
+        'scope': "Select the context scope.",
         'filter': "Use a regex pattern to filter result by the provider.",
+        'context': "Specify the context to be used.",
+        'namespace': "Override the namespace in the context.",
+        'project': "Override the project in the context.",
+        'application': "Override the application in the context.",
 
     },
     'parameter': {
@@ -185,7 +200,7 @@ CLI_PARAMETERS_HELP = {
         'limit': "Limit templates to be rendered.",
         'render_path': "Path (relative to the root of the DSO application) where rendered template will be placed at.",
         'query_render_path': "Include the template render paths in the output.",
-        'input' : "Path to a local file containing the template content.",
+        'contents_path' : "Path to a local file or directory containing the template contents.",
         'recursive' : "Add files recursively.",
         'uninherited': "Select only templates which are specific to the gievn context, i.e. not inherited from the parent contexts.",
         'include_contents': "Include template contenets in the output. ",
@@ -196,11 +211,15 @@ CLI_PARAMETERS_HELP = {
         'key': "The key of the configuration",
         'value': 'Value for the configuration key',
         'input' : "Path to a local (yaml) file inputing the configuration. Use '-' to read from the shell pipe or stdin.",
-        'local': "Select only the local DSO configurations, i.e. existing in the working directory.",
-        'global': "Select only the global DSO configurations, i.e. user-wide configuration.",
-        'init_local': "Explicitly override inherited configurations locally. If mixed with '-i' / '--input' option, it will casue the local configuration to be merged with the provided input configuration.",
+        'local': "Select the local DSO configurations, i.e. existing in the working directory.",
+        'global': "Select the global DSO configurations, i.e. user-wide configuration.",
+        'override_inherited': "Explicitly override inherited configurations locally.",
         'setup': "Run a setup wizard to assist configuring the DSO application.",
 
+    },
+    'network': {
+        'subnet_layout_mode': "Select the subnet plan layout mode.",
+    
     }
 
 
@@ -210,11 +229,13 @@ CLI_PARAMETERS_HELP = {
 CLI_MESSAGES = {
     'MissingOption': "Missing option {0}.",
     'MissingArgument': "Missing argument {0}.",
+    'ArgumentsProvided': "The following argument/option must be provided: {1}",
     'ArgumentsOnlyOneProvided': "Only one of the following arguments/options may be provided: {0}",
     'ArgumentsAtLeastOneProvided': "At least one of the following arguments/options must be provided: {0}",
-    'ArgumentsAllProvided': "All of the following arguments/options must be provide: {0}",
+    'ArgumentsAllProvided': "All of the following arguments/options must be provided: {0}",
     'ArgumentsNoneProvided': "The following arguments/options cannot be provided: {0}",
     'ArgumentsNotAllProvided': "The following arguments/options cannot be provided together: {0}",
+    'ArgumentsProvidedBecause': "Since {0} provided, the following argument/option must also be provide: {1}",
     'ArgumentsOnlyOneProvidedBecause': "Since {0} provided, only one of the following arguments/options may be provided: {1}",
     'ArgumentsAtLeastOneProvidedBecause': "Since {0} provided, at least one of the following arguments/options must also be provided: {1}",
     'ArgumentsAllProvidedBecause': "Since {0} provided, all of the following arguments/options must also be provide: {1}",
@@ -229,7 +250,8 @@ CLI_MESSAGES = {
     'InvalidRenderPathExistingDir': "'{0}' is not a valid render path because it is an existing directory.",
     'InvalidFilter': "Invalid regex pattern for filter: {0}",
     'NoChanegeDetectedAfterEditing': "No change detected after editing.",
-    'ParameterNotFound': "Parameter '{0}' not found in the given context: project={1}, application={2}, stage={3}",
-    'SecretNotFound': "Secret '{0}' not found in the given context: project={1}, application={2}, stage={3}",
-    'TemplateNotFound': "Template '{0}' not found in the given context: project={1}, application={2}, stage={3}",
+    'ParameterNotFound': "Parameter '{0}' not found in the given context: namespace={1}, project={2}, application={3}, stage={4}, scope={5}",
+    'SecretNotFound': "Secret '{0}' not found in the given context: namespace={1}, project={2}, application={3}, stage={4}, scope={5}",
+    'TemplateNotFound': "Template '{0}' not found in the given context: namespace={1}, project={2}, application={3}, stage={4}, scope={5}",
+    'MissingField': "Missing field: {0}",
 }
