@@ -180,7 +180,8 @@ class ConfigService:
         for dir in Path(self.working_dir).resolve().parents:
             configFilePath = os.path.join(dir, self.config_dir, self.config_file)
             if os.path.exists(configFilePath):
-                if not os.path.samefile(configFilePath, self.global_config_file_path):
+                # if not os.path.samefile(configFilePath, self.global_config_file_path):
+                if not os.path.abspath(configFilePath) == os.path.abspath(self.global_config_file_path):
                     Logger.debug(f"Inherited DSO configuration found: path={configFilePath}")
                     self.inherited_config_files.append(configFilePath)
 
