@@ -45,7 +45,7 @@ def load_templates_from_path(result, config, path, path_prefix='', include_conte
             if filter and not re.match(filter, key): continue
             if key in result:
                 Logger.warn(f"Inherited template '{key}' has been overridden.")
-            ctx_path = os.path.abspath(filePath)[len(os.path.abspath(config.working_dir)) + 1 + len(path_prefix):]
+            ctx_path = os.path.abspath(filePath)[len(os.path.abspath(config.working_dir)) + 1 + len(path_prefix):].replace(os.sep, '/')
             ctx = Context(*Contexts.parse_path(ctx_path)[0:4])
             result[key] = {
                 'Stage': ctx.short_stage,
@@ -95,7 +95,7 @@ def add_local_template(config, key, path_prefix, contents):
     os.makedirs(os.path.dirname(fullPath), exist_ok=True)
     with open(fullPath, 'w', encoding='utf-8') as f:
         f.write(contents)
-    ctx_path = path[len(path_prefix):]
+    ctx_path = path[len(path_prefix):].replace(os.sep, '/')
     ctx = Context(*Contexts.parse_path(ctx_path)[0:4])
     result = {
         'Contents': contents,
@@ -125,7 +125,7 @@ def load_parameter_store(result, config, path, path_prefix='', filter=None):
         if filter and not re.match(filter, key): continue
         if key in result:
             Logger.warn(f"Inherited parameter '{key}' has been overridden.")
-        ctx_path = path[len(path_prefix):]
+        ctx_path = path[len(path_prefix):].replace(os.sep, '/')
         ctx = Context(*Contexts.parse_path(ctx_path)[0:4])
         result[key] = {
             'Value': value,
@@ -147,7 +147,7 @@ def get_context_hierachy_parameter_stores(context, store_name, path_prefix='', u
     paths = get_context_hierachy_local_paths(context=context, path_prefix=path_prefix, uninherited=uninherited, reverse=reverse)
     stores = []
     for path in paths:
-        ctx_path = path[len(path_prefix):]
+        ctx_path = path[len(path_prefix):].replace(os.sep, '/')
         ctx = Context(*Contexts.parse_path(ctx_path)[0:4])
         stores.append({
             'Stage': ctx.short_stage,
@@ -194,16 +194,18 @@ def add_local_parameter(config, key, value, store_name, path_prefix=''):
     params = load_file(file_path=fullPath)
     set_dict_value(dic=params, keys=key.split('.'), value=value, overwrite_parent=False, overwrite_children=False)
     save_data(data=params, file_path=fullPath)
+    ctx_path = path[len(path_prefix):].replace(os.sep, '/')
+    ctx = Context(*Contexts.parse_path(ctx_path)[0:4])
     result = {
         'Key': key,
         'Value': value,
         'Stage': config.short_stage,
         'Scope': config.context.scope_translation,
         'Origin': {
-            'Namespace': Contexts.parse_path(path[len(path_prefix):])[0],
-            'Project': Contexts.parse_path(path[len(path_prefix):])[1],
-            'Application': Contexts.parse_path(path[len(path_prefix):])[2],
-            'Stage': Contexts.parse_path(path[len(path_prefix):])[3],
+            'Namespace': ctx.namespace,
+            'Project': ctx.project,
+            'Application': ctx.application,
+            'Stage': ctx.stage,
         },
         'Path': path,
 
