@@ -65,7 +65,7 @@ class AwsSsmParameterProvider(ParameterProvider):
                     'Namespace': config.namespace,
                     'Project': config.project,
                     'Application': config.application,
-                    'Stage': config.short_stage,
+                    'Stage': config.stage,
                 },
                 'Path': path,
             }
