@@ -71,7 +71,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     'Namespace': config.namespace,
                     'Project': config.project,
                     'Application': config.application,
-                    'Stage': config.short_stage,
+                    'Stage': config.stage,
                 },
                 'Path': path,
             }
